__title__ = 'i2plib'
__description__ = 'A modern asynchronous library for building I2P applications.'
__url__ = 'https://github.com/l-n-s/i2plib'
__version__ = '0.0.8'
__author__ = 'Viktor Villainov'
__author_email__ = 'supervillain@riseup.net'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Viktor Villainov'



"""
A modern asynchronous library for building I2P applications. 
"""

from .__version__ import (
    __title__, __description__, __url__, __version__,
    __author__, __author_email__, __license__, __copyright__
)

from .sam import Destination, PrivateKey

from .aiosam import (
    get_sam_socket, dest_lookup, new_destination, 
    create_session, stream_connect, stream_accept
)

from .tunnel import ClientTunnel, ServerTunnel

from .utils import get_sam_address

from .exceptions import (
     CantReachPeer, DuplicatedDest, DuplicatedId, I2PError,
     InvalidId, InvalidKey, KeyNotFound, PeerNotFound, Timeout,
)



#!/usr/bin/env python3

from setuptools import setup
import os

with open("README.rst") as readme:
    long_description = readme.read()

about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'i2plib', '__version__.py'), 'r') as f:
    exec(f.read(), about)

setup(
    name=about['__title__'],
    version=about['__version__'],
    description=about['__description__'],
    long_description=long_description,
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    keywords='i2p',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=['i2plib'],
)
